@@ -95,7 +95,7 @@ def wrap_api_client_with_retries(api_client: DefaultApi) -> DefaultApi:
     @wrapt.decorator  # type: ignore
     def retrier(
         func: Any, instance: Any, args: List[Any], kwargs: Any  # noqa: ARG001
-    ) -> Any:  # noqa: ARG001
+    ) -> Any:
         for i in range(RETRY_COUNT):
             try:
                 return func(*args, **kwargs)
