@@ -119,7 +119,7 @@ def get_last_used_cloud(
     else:
         # TODO(nikita): Add some logics or checks here so users don't start clusters with clouds
         # they don't intend to.
-        clouds = get_all_clouds()
+        clouds = get_all_clouds(anyscale_api_client)
         if len(clouds) > 0:
             # Clouds are sorted in descending order, pick the oldest one as default.
             cloud = clouds[-1]
@@ -129,7 +129,7 @@ def get_last_used_cloud(
             )
 
     cloud_name = cloud.name
-    log.info(
+    log.debug(
         f"Using last active cloud '{cloud_name}'. "
         "Specify `cloud` in the command to overwrite."
     )
@@ -158,3 +158,24 @@ def get_all_clouds(anyscale_api_client: Optional[DefaultApi] = None) -> List[Clo
         all_clouds.extend(cloud_list_response.results)
 
     return all_clouds  # type: ignore
+
+
+def get_organization_default_cloud(api_client: DefaultApi) -> Optional[str]:
+    """Return default cloud name for organization if it exists and
+    if user has correct permissions for it.
+    Returns:
+        Name of default cloud name for organization if it exists and
+        if user has correct permissions for it.
+    """
+    user = api_client.get_user_info_api_v2_userinfo_get().result
+    organization = user.organizations[0]  # Each user only has one org
+    if organization.default_cloud_id:
+        try:
+            # Check permissions
+            _, cloud_name = get_cloud_id_and_name(
+                api_client, cloud_id=organization.default_cloud_id
+            )
+            return str(cloud_name)
+        except Exception:  # noqa: BLE001
+            return None
+    return None
