@@ -36,16 +36,16 @@ from anyscale.utils.s3 import verify_s3_access
 DEFAULT_RAY_IAM_ROLE = "ray-autoscaler-v1"
 
 
-class CAPACITY_THRESHOLDS:  # noqa: N801
+class CAPACITY_THRESHOLDS:
     """
     These are various constants for resources capacity we want to ensure we meet.
     """
 
-    class AWS_VPC:  # noqa: N801
+    class AWS_VPC:
         HOSTS_MIN: int = ipaddress.ip_network("10.0.0.0/24").num_addresses
         HOSTS_WARN: int = ipaddress.ip_network("10.0.0.0/20").num_addresses
 
-    class AWS_SUBNET:  # noqa: N801
+    class AWS_SUBNET:
         HOSTS_MIN: int = ipaddress.ip_network("10.0.0.0/28").num_addresses
         HOSTS_WARN: int = ipaddress.ip_network("10.0.0.0/24").num_addresses
 
@@ -369,10 +369,6 @@ def verify_aws_security_groups(
     if not cloud_resource.aws_security_groups:
         logger.error("Missing security group IDs.")
         return False
-    if len(cloud_resource.aws_security_groups) > 1:
-        logger.warning(
-            "Multiple security groups provided. Only taking the first security group and ignoring the rest."
-        )
 
     ec2 = boto3_session.resource("ec2")
     anyscale_security_group_arn = cloud_resource.aws_security_groups[0]
