@@ -134,9 +134,7 @@ def configure_for_session(
     project_root_dir: Optional[str] = None,
     api_client: Optional[DefaultApi] = None,
     disable_project_sync: bool = False,
-    _DO_NOT_USE_RAY_UP_ONLY_cluster_config: Optional[  # noqa: N803
-        Dict[str, Any]
-    ] = None,
+    _DO_NOT_USE_RAY_UP_ONLY_cluster_config: Optional[Dict[str, Any]] = None,
 ) -> Dict[str, Any]:
     """
     This method constructs the relevant cluster config for a cluster
