@@ -31,7 +31,7 @@ def get_default_cluster_env_build(
         ).result.id
         build = anyscale_api_client.get_cluster_environment_build(build_id).result
         return build
-    except Exception:
+    except Exception:  # noqa: BLE001
         raise RuntimeError(
             f"Failed to get default cluster env for Ray: {ray_version} on Python: py{py_version}"
         )
@@ -118,9 +118,7 @@ def get_cluster_env_from_name(
         if cluster_env.name == cluster_env_name:
             return cluster_env
 
-    raise click.ClickException(
-        "Cluster environment '{}' not found.".format(cluster_env_name)
-    )
+    raise click.ClickException(f"Cluster environment '{cluster_env_name}' not found.")
 
 
 def list_builds(
