@@ -3,6 +3,7 @@ from typing import List, Optional
 import click
 
 from anyscale.cli_logger import BlockLogger
+from anyscale.client.openapi_client.models import ClusterManagementStackVersions
 from anyscale.commands.util import OptionPromptNull
 from anyscale.controllers.cloud_controller import CloudController
 
@@ -126,6 +127,13 @@ def cloud_set_default(
     default=False,
     help="Let anyscale create all the resources.",
 )
+@click.option(
+    "--use-legacy-stack",
+    is_flag=True,
+    default=False,
+    hidden=True,
+    help="Whether to use the legacy stack.",
+)
 def setup_cloud(  # noqa: PLR0913
     provider: str,
     region: str,
@@ -133,12 +141,17 @@ def setup_cloud(  # noqa: PLR0913
     yes: bool,
     gce: bool,
     anyscale_managed: bool,
+    use_legacy_stack: bool,
     gcp_folder_id: Optional[int],
     vpc_peering_ip_range: Optional[str],
     vpc_peering_target_project_id: Optional[str],
     vpc_peering_target_vpc_id: Optional[str],
 ) -> None:
-
+    cluster_management_stack_version = (
+        ClusterManagementStackVersions.V1
+        if use_legacy_stack
+        else ClusterManagementStackVersions.V2,
+    )
     if provider == "aws":  # only provides Anyscale Managed option for AWS
         if (
             vpc_peering_ip_range
@@ -154,6 +167,7 @@ def setup_cloud(  # noqa: PLR0913
             name=name,
             yes=yes,
             folder_id=gcp_folder_id,
+            cluster_management_stack_version=cluster_management_stack_version,
         )
     elif provider == "gcp":
         if anyscale_managed:
@@ -163,6 +177,7 @@ def setup_cloud(  # noqa: PLR0913
                 name=name,
                 yes=yes,
                 folder_id=gcp_folder_id,
+                cluster_management_stack_version=cluster_management_stack_version,
             )
         else:
             CloudController().setup_cloud(
@@ -369,6 +384,13 @@ def cloud_secrets(
 @click.option(
     "--private-network", help="Use private network.", is_flag=True, default=False,
 )
+@click.option(
+    "--use-legacy-stack",
+    is_flag=True,
+    default=False,
+    hidden=True,
+    help="Whether to use the legacy stack.",
+)
 def register_cloud(  # noqa: PLR0913
     provider: str,
     region: str,
@@ -381,6 +403,7 @@ def register_cloud(  # noqa: PLR0913
     security_group_ids: str,
     s3_bucket_id: str,
     private_network: bool,
+    use_legacy_stack: bool,
 ) -> None:
 
     if provider == "aws":
@@ -411,6 +434,9 @@ def register_cloud(  # noqa: PLR0913
             security_group_ids=security_group_ids.split(","),
             s3_bucket_id=s3_bucket_id,
             private_network=private_network,
+            cluster_management_stack_version=ClusterManagementStackVersions.V1
+            if use_legacy_stack
+            else ClusterManagementStackVersions.V2,
         )
     elif provider == "gcp":
         # TODO (allenyin): implement this
