@@ -182,6 +182,16 @@ def init(project_id: Optional[str], name: Optional[str],) -> None:
     prompt=True,
     default=_default_project_name(),
 )
-def create(name: str) -> None:
+@click.option(
+    "--parent-cloud-id",
+    required=False,
+    default=None,
+    help=(
+        "Cloud id that this project is associated with. This argument "
+        "is only relevant if cloud isolation is enabled."
+    ),
+    hidden=True,
+)
+def create(name: str, parent_cloud_id: str) -> None:
     project_controller = ProjectController()
-    project_controller.create(name)
+    project_controller.create(name, parent_cloud_id)
