@@ -21,16 +21,6 @@ from anyscale.util import get_endpoint
 from anyscale.workspace import get_workspace_root_or_throw, write_workspace_id_to_disk
 
 
-ANYSCALE_WORKSPACES_SSH_OPTIONS = [
-    "-o",
-    "StrictHostKeyChecking=no",
-    "-o",
-    "UserKnownHostsFile=/dev/null",
-    "-o",
-    "IdentitiesOnly=yes",
-]
-
-
 @click.group("workspace", help="Interact with workspaces on Anyscale.")
 def workspace_cli() -> None:
     pass
@@ -282,9 +272,7 @@ def run(command: str, web_terminal: bool, as_job: bool, no_push: bool,) -> None:
         )
         print()
     else:
-        workspace_controller.run_cmd(
-            ANYSCALE_WORKSPACES_SSH_OPTIONS, f"cd ~/{dir_name} && {command}",
-        )
+        workspace_controller.run_cmd(f"cd ~/{dir_name} && {command}")
 
 
 @workspace_cli.command(name="ssh", help="ssh into a workspace")
@@ -296,9 +284,7 @@ def ssh() -> None:
 
     workspace_controller = WorkspaceController()
     dir_name = workspace_controller.get_workspace_dir_name()
-    workspace_controller.run_cmd(
-        ANYSCALE_WORKSPACES_SSH_OPTIONS, f"cd ~/{dir_name} && /bin/bash",
-    )
+    workspace_controller.run_cmd(f"cd ~/{dir_name} && /bin/bash")
 
 
 def _do_pull(pull_git_state):
@@ -308,12 +294,9 @@ def _do_pull(pull_git_state):
     # a repack prior to pulling. Otherwise, the pulled git repo may not be fully
     # functional locally. A repack is expensive, but we assume pulls aren't frequent.
     if pull_git_state:
-        workspace_controller.run_cmd(
-            ANYSCALE_WORKSPACES_SSH_OPTIONS, f"cd ~/{dir_name} && git repack -a -d",
-        )
+        workspace_controller.run_cmd(f"cd ~/{dir_name} && git repack -a -d")
     workspace_root = get_workspace_root_or_throw()
     workspace_controller.run_rsync(
-        ANYSCALE_WORKSPACES_SSH_OPTIONS,
         workspace_root,
         down=True,
         rsync_filters=[".gitignore"],
@@ -326,7 +309,6 @@ def _do_push(push_git_state):
     workspace_controller = WorkspaceController()
     workspace_root = get_workspace_root_or_throw()
     workspace_controller.run_rsync(
-        ANYSCALE_WORKSPACES_SSH_OPTIONS,
         workspace_root,
         down=False,
         rsync_filters=[".gitignore"],
