@@ -164,7 +164,7 @@ class ClientBuilder:
         >>> [0, 1, 4, 9, 16]
     """
 
-    def __init__(  # noqa: PLR0913, PLR0915
+    def __init__(
         self,
         address: Optional[str] = None,
         anyscale_sdk: AnyscaleSDK = None,
@@ -186,6 +186,12 @@ class ClientBuilder:
             self._log = log
         else:
             self._log = BlockLogger()
+        self._log.warning(
+            "DEPRECATION WARNING: Anyscale Connect will be deprecated in future Anyscale versions. "
+            "Please use workspaces: "
+            "https://docs.anyscale.com/user-guide/develop-and-debug/workspaces or Ray Jobs "
+            "https://docs.anyscale.com/user-guide/develop-and-debug/ray-jobs-support instead."
+        )
         if anyscale_sdk:
             self._anyscale_sdk = anyscale_sdk
         else:
@@ -353,7 +359,7 @@ class ClientBuilder:
                     f"{key}. The supported parameters are: {CONNECT_URL_PARAMS}."
                 )
 
-    def _init_args(self, **kwargs) -> "ClientBuilder":  # noqa: C901, PLR0912
+    def _init_args(self, **kwargs) -> "ClientBuilder":  # noqa: PLR0912
         """
         Accepts arguments from ray.init when called with anyscale protocol,
         i.e. ray.init("anyscale://someCluster", arg1="thing", arg2="other").
@@ -794,7 +800,7 @@ class ClientBuilder:
                 "full Serve session URL for Serve deployments."
             )
 
-    def connect(self) -> AnyscaleClientContext:  # noqa
+    def connect(self) -> AnyscaleClientContext:
         """Connect to Anyscale using previously specified options.
 
         Examples:
@@ -829,7 +835,11 @@ class ClientBuilder:
             self._exec_self_in_local_docker()
 
         self._project_block = create_project_block(
-            self._project_dir, self._project_name
+            self._project_dir,
+            self._project_name,
+            cloud_name=self._cloud_name,
+            cluster_compute_name=self._cluster_compute_name,
+            cluster_compute_dict=self._cluster_compute_dict,
         )
         project_id = self._project_block.project_id
         project_dir = self._project_block.project_dir
