@@ -2,7 +2,7 @@ from datetime import datetime
 from enum import Enum
 import sys
 import time
-from typing import Any, cast, Dict, List, Optional, Tuple, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
 
 from packaging import version
 
@@ -10,7 +10,11 @@ from anyscale.authenticate import get_auth_api_client
 from anyscale.cli_logger import BlockLogger
 from anyscale.client.openapi_client.models.build import Build
 from anyscale.client.openapi_client.models.session import Session
-from anyscale.cloud import get_cloud_id_and_name
+from anyscale.cloud import (
+    get_cloud_id_and_name,
+    get_last_used_cloud,
+    get_organization_default_cloud,
+)
 from anyscale.conf import MINIMUM_RAY_VERSION
 from anyscale.links import DOCS_CLUSTER
 from anyscale.sdk.anyscale_client import (
@@ -21,11 +25,11 @@ from anyscale.sdk.anyscale_client import (
     StartClusterOptions,
     UpdateCluster,
 )
-from anyscale.sdk.anyscale_client.models.cloud import Cloud
 from anyscale.sdk.anyscale_client.models.compute_template import ComputeTemplate
 from anyscale.sdk.anyscale_client.models.session_state import SessionState
 from anyscale.util import generate_slug, get_endpoint, wait_for_session_start
 from anyscale.utils.connect_helpers import get_cluster, list_entities
+from anyscale.utils.name_utils import gen_valid_name
 
 
 # Max number of auto created clusters.
@@ -236,7 +240,7 @@ class PrepareClusterBlock:
 
         self.log.close_block(self.block_label)
 
-    def _start_or_create_cluster(  # noqa: C901, PLR0913
+    def _start_or_create_cluster(
         self,
         project_id: str,
         build_id: str,
@@ -306,7 +310,7 @@ class PrepareClusterBlock:
             allow_public_internet_traffic,
         )
 
-    def _start_cluster_if_required(  # noqa: PLR0913
+    def _start_cluster_if_required(
         self,
         cluster: Session,
         start_required: bool,
@@ -639,7 +643,7 @@ class PrepareClusterBlock:
         assert build_to_use  # for mypy
         return build_to_use
 
-    def _build_cluster_env_if_needed(  # noqa: PLR0913
+    def _build_cluster_env_if_needed(
         self,
         project_id: str,
         build_pr: Optional[int],
@@ -813,7 +817,7 @@ class PrepareClusterBlock:
         Register compute template with a default name and return the compute template id."""
         created_template = self.api_client.create_compute_template_api_v2_compute_templates_post(
             create_compute_template=CreateComputeTemplate(
-                name=f"autogenerated-config-{datetime.now().isoformat()}",
+                name=gen_valid_name("autogenerated-config"),
                 project_id=project_id,
                 config=config_object,
                 anonymous=True,
@@ -847,89 +851,14 @@ class PrepareClusterBlock:
         """
 
         if cloud_name is None:
-            default_cloud_name = self._get_organization_default_cloud()
+            default_cloud_name = get_organization_default_cloud(self.api_client)
             if default_cloud_name:
                 cloud_name = default_cloud_name
             else:
-                cloud_name = self._get_last_used_cloud(project_id)
+                cloud_name = get_last_used_cloud(project_id, self.anyscale_api_client)
         cloud_id, _ = get_cloud_id_and_name(self.api_client, cloud_name=cloud_name)
         return cloud_id
 
-    def _get_organization_default_cloud(self) -> Optional[str]:
-        """Return default cloud name for organization if it exists and
-        if user has correct permissions for it.
-        Returns:
-            Name of default cloud name for organization if it exists and
-            if user has correct permissions for it.
-        """
-        user = self.api_client.get_user_info_api_v2_userinfo_get().result
-        organization = user.organizations[0]  # Each user only has one org
-        if organization.default_cloud_id:
-            try:
-                # Check permissions
-                _, cloud_name = get_cloud_id_and_name(
-                    self.api_client, cloud_id=organization.default_cloud_id
-                )
-                return str(cloud_name)
-            except Exception:  # noqa: BLE001
-                return None
-        return None
-
-    def _get_last_used_cloud(self, project_id: str) -> str:
-        """Return the name of the cloud last used in the project.
-        Args:
-            project_id (str): The project to get the last used cloud for.
-        Returns:
-            Name of the cloud last used in this project.
-        """
-        # TODO(pcm): Get rid of this and the below API call in the common case where
-        # we can determine the cloud to use in the backend.
-        cloud_id = self.anyscale_api_client.get_project(
-            project_id
-        ).result.last_used_cloud_id
-        if cloud_id:
-            try:
-                cloud = self.anyscale_api_client.get_cloud(cloud_id).result
-            except Exception:  # noqa: BLE001
-                raise RuntimeError(f"Failed to fetch Cloud with id: {cloud_id}.")
-        else:
-            clouds = self._get_all_clouds()
-            if len(clouds) > 0:
-                # Clouds are sorted in descending order, pick the oldest one as default.
-                cloud = clouds[-1]
-            else:
-                raise RuntimeError(
-                    "No cloud configured, please set up a cloud with 'anyscale cloud setup'."
-                )
-
-        cloud_name = cloud.name
-        self.log.debug(
-            f"Using last active cloud '{cloud_name}'. "
-            "Call anyscale.cloud('...').connect() to overwrite."
-        )
-        return cast(str, cloud_name)
-
-    def _get_all_clouds(self) -> List[Cloud]:
-        """Fetches all Clouds the user has access to.
-        Returns:
-            List of all Clouds the user has access to.
-        """
-
-        cloud_list_response = self.anyscale_api_client.search_clouds(
-            {"paging": {"count": 50}}
-        )
-        all_clouds = cloud_list_response.results
-        next_paging_token = cloud_list_response.metadata.next_paging_token
-
-        while next_paging_token:
-            cloud_list_response = self.anyscale_api_client.search_clouds(
-                {"paging": {"count": 50, "paging_token": next_paging_token}}
-            )
-            next_paging_token = cloud_list_response.metadata.next_paging_token
-            all_clouds.extend(cloud_list_response.results)
-
-        return all_clouds  # type: ignore
-
     def _validate_new_cluster_compute_and_env_match_existing_cluster(
         self, project_id: str, running_cluster: Session, print_warnings: bool = True
     ) -> bool:
