@@ -1,5 +1,5 @@
 import os
-from typing import Optional, Tuple
+from typing import Any, Dict, Optional, Tuple
 
 import click
 import yaml
@@ -7,10 +7,24 @@ import yaml
 import anyscale
 from anyscale.authenticate import get_auth_api_client
 from anyscale.cli_logger import BlockLogger
+from anyscale.cloud import (
+    get_cloud_id_and_name,
+    get_last_used_cloud,
+    get_organization_default_cloud,
+)
 import anyscale.conf
+from anyscale.sdk.anyscale_client import (
+    ComputeTemplateConfig,
+    ComputeTemplateQuery,
+)
 from anyscale.utils.connect_helpers import find_project_id
 
 
+# The cluster compute type. It can either be a string, eg my_template or a dict,
+# eg, {"cloud_id": "id-123" ...}
+CLUSTER_COMPUTE_DICT_TYPE = Dict[str, Any]
+
+
 class ProjectBlock:
     """
     Class to determine which project ray.client uses. This class should never be
@@ -22,6 +36,9 @@ class ProjectBlock:
         self,
         project_dir: Optional[str] = None,
         project_name: Optional[str] = None,
+        cloud_name: Optional[str] = None,
+        cluster_compute_name: Optional[str] = None,
+        cluster_compute_dict: Optional[CLUSTER_COMPUTE_DICT_TYPE] = None,
         log_output: bool = True,
     ):
         """
@@ -36,6 +53,9 @@ class ProjectBlock:
             project_name (Optional[str]): Project name if it is necessary to register the project
                 with Anyscale. This will not be used if a registered project already exists
                 in the project_dir.
+            cloud_name (Optional[str]): This argument is only relevant if cloud isolation is enabled.
+                If cloud_name is specified and no project arguements are specified, take the default
+                project of the cloud.
         """
         self.log = BlockLogger(log_output=log_output)
         auth_api_client = get_auth_api_client(log_output=log_output)
@@ -44,6 +64,9 @@ class ProjectBlock:
         self.project_dir = (
             os.path.abspath(os.path.expanduser(project_dir)) if project_dir else None
         )
+        self.cloud_name = cloud_name
+        self.cluster_compute_name = cluster_compute_name
+        self.cluster_compute_dict = cluster_compute_dict
 
         self.block_label = "Project"
         self.log.open_block(self.block_label, block_title="Choosing a project")
@@ -51,11 +74,15 @@ class ProjectBlock:
         if self.project_dir is None and project_name is None:
             self.project_dir = anyscale.project.find_project_root(os.getcwd())
 
+        parent_cloud_id = self._get_parent_cloud_id(
+            self.cloud_name, self.cluster_compute_name, self.cluster_compute_dict
+        )
+
         left_pad = " " * 2
         if self.project_dir:
             # TODO(nikita): Remove this logic when removing .anyscale.yaml in Q3 2022
             self.project_id, self.project_name = self._ensure_project_setup_at_dir(
-                self.project_dir, project_name
+                self.project_dir, project_name, parent_cloud_id
             )
             self.log.info(
                 f"{left_pad}{'name:': <20}{self.project_name}",
@@ -71,7 +98,7 @@ class ProjectBlock:
             )
         elif project_name:
             self.project_id, self.project_name = self._create_or_get_project_from_name(
-                project_name
+                project_name, parent_cloud_id
             )
             self.log.info(
                 f"{left_pad}{'name:': <20}{self.project_name}",
@@ -82,17 +109,23 @@ class ProjectBlock:
                 block_label=self.block_label,
             )
         else:
-            self.project_id, self.project_name = self._get_default_project()
+            self.project_id, self.project_name = self._get_default_project(
+                parent_cloud_id
+            )
         self.log.close_block(self.block_label)
 
-    def _get_default_project(self) -> Tuple[str, str]:
+    def _get_default_project(
+        self, parent_cloud_id: Optional[str] = None
+    ) -> Tuple[str, str]:
         """
         Get default project id and name.
 
         Returns:
         The project id and project name of the project being used.
         """
-        default_project = self.anyscale_api_client.get_default_project().result
+        default_project = self.anyscale_api_client.get_default_project(
+            parent_cloud_id=parent_cloud_id
+        ).result
         project_id = default_project.id
         project_name = default_project.name
         self.log.info(
@@ -101,8 +134,50 @@ class ProjectBlock:
         )
         return project_id, project_name
 
+    def _get_parent_cloud_id(
+        self,
+        cloud_name: Optional[str],
+        cluster_compute_name: Optional[str],
+        cluster_compute_dict: Optional[CLUSTER_COMPUTE_DICT_TYPE],
+    ) -> Optional[str]:
+        parent_cloud_id = None
+        if cloud_name:
+            parent_cloud_id, _ = get_cloud_id_and_name(
+                api_client=self.api_client, cloud_id=None, cloud_name=cloud_name,
+            )
+        elif cluster_compute_name:
+            cluster_computes = self.api_client.search_compute_templates_api_v2_compute_templates_search_post(
+                ComputeTemplateQuery(
+                    orgwide=True,
+                    name={"equals": cluster_compute_name},
+                    include_anonymous=True,
+                )
+            ).results
+            if len(cluster_computes) == 0:
+                raise click.ClickException(
+                    f"The cluster compute template {cluster_compute_name} does not exist."
+                )
+            parent_cloud_id = cluster_computes[0].config.cloud_id
+        elif cluster_compute_dict:
+            cluster_compute_config_obj = ComputeTemplateConfig(**cluster_compute_dict)
+            parent_cloud_id = cluster_compute_config_obj.cloud_id
+        else:
+            # Get organization default cloud or last used cloud
+            default_cloud_name = get_organization_default_cloud(self.api_client)
+            if default_cloud_name:
+                cloud_name = default_cloud_name
+            else:
+                cloud_name = get_last_used_cloud(None, self.anyscale_api_client)
+            parent_cloud_id, _ = get_cloud_id_and_name(
+                self.api_client, cloud_id=None, cloud_name=cloud_name
+            )
+        return parent_cloud_id
+
     def _ensure_project_setup_at_dir(
-        self, project_dir: str, project_name: Optional[str]
+        self,
+        project_dir: str,
+        project_name: Optional[str],
+        parent_cloud_id: Optional[str] = None,
     ) -> Tuple[str, str]:
         """
         Get or create an Anyscale project rooted at the given dir. If .anyscale.yaml
@@ -157,6 +232,7 @@ class ProjectBlock:
                 {
                     "name": project_name,
                     "description": "Automatically created by Anyscale Connect",
+                    "parent_cloud_id": parent_cloud_id,
                 }
             )
             project_id = project_response.result.id
@@ -178,7 +254,9 @@ class ProjectBlock:
 
         return project_id, project_name
 
-    def _create_or_get_project_from_name(self, project_name: str) -> Tuple[str, str]:
+    def _create_or_get_project_from_name(
+        self, project_name: str, parent_cloud_id: Optional[str] = None
+    ) -> Tuple[str, str]:
         """
         Get or create an Anyscale project not rooted in any directory
         (without .anyscale.yaml).
@@ -196,6 +274,7 @@ class ProjectBlock:
                 {
                     "name": project_name,
                     "description": "Automatically created by Anyscale Connect",
+                    "parent_cloud_id": parent_cloud_id,
                 }
             )
             project_id = project_response.result.id
@@ -209,6 +288,9 @@ class ProjectBlock:
 def create_project_block(
     project_dir: Optional[str] = None,
     project_name: Optional[str] = None,
+    cloud_name: Optional[str] = None,
+    cluster_compute_name: Optional[str] = None,
+    cluster_compute_dict: Optional[CLUSTER_COMPUTE_DICT_TYPE] = None,
     log_output: bool = True,
 ):
     """
@@ -217,5 +299,10 @@ def create_project_block(
     get_project_block.
     """
     return ProjectBlock(
-        project_dir=project_dir, project_name=project_name, log_output=log_output
+        project_dir=project_dir,
+        project_name=project_name,
+        cloud_name=cloud_name,
+        cluster_compute_name=cluster_compute_name,
+        cluster_compute_dict=cluster_compute_dict,
+        log_output=log_output,
     )
