@@ -31,6 +31,7 @@ from anyscale.cli_logger import LogsLogger
 from anyscale.client.openapi_client.models import (
     CloudConfig,
     CloudWithCloudResource,
+    ClusterManagementStackVersions,
     CreateCloudResource,
     UpdateCloudWithCloudResource,
     WriteCloud,
@@ -376,7 +377,10 @@ class CloudController(BaseController):
         )
 
     def prepare_for_managed_cloud_setup(
-        self, region: str, cloud_name: str
+        self,
+        region: str,
+        cloud_name: str,
+        cluster_management_stack_version: ClusterManagementStackVersions,
     ) -> Tuple[str, str]:
         regions_available = get_available_regions()
         if region not in regions_available:
@@ -408,16 +412,18 @@ class CloudController(BaseController):
                 ).to_string(),
                 name=cloud_name,
                 is_bring_your_own_resource=False,
+                cluster_management_stack_version=cluster_management_stack_version,
             )
         ).result
 
         return anyscale_iam_role_name, created_cloud.id
 
-    def setup_managed_cloud(  # noqa: PLR0913
+    def setup_managed_cloud(
         self,
         provider: str,
         region: str,
         name: str,
+        cluster_management_stack_version: ClusterManagementStackVersions,
         yes: bool = False,  # noqa: ARG002
         folder_id: Optional[int] = None,  # noqa: ARG002
     ) -> None:
@@ -429,7 +435,9 @@ class CloudController(BaseController):
                 (
                     anyscale_iam_role_name,
                     cloud_id,
-                ) = self.prepare_for_managed_cloud_setup(region, name)
+                ) = self.prepare_for_managed_cloud_setup(
+                    region, name, cluster_management_stack_version
+                )
 
             try:
                 cfn_stack = self.run_cloudformation(
@@ -755,31 +763,27 @@ class CloudController(BaseController):
     def _experimental_grant_secrets_access_gcp(
         self, cloud: CloudWithCloudResource, write_permissions: bool, yes: bool
     ) -> None:
-        import google.auth
-        from oauth2client.client import GoogleCredentials
+        from anyscale.utils.gcp_utils import get_application_default_credentials
 
-        discovery = try_import_gcp_discovery()
+        (
+            credentials,
+            default_credentials_project_name,
+        ) = get_application_default_credentials(self.log)
 
-        credentials = GoogleCredentials.get_application_default()
-        projects_client = discovery.build(
-            "cloudresourcemanager", "v3", credentials=credentials
-        ).projects()
-
-        gcloud_credentials_project_name = google.auth.default()[1]
         anyscale_cloud_project_name = json.loads(cloud.credentials)["project_id"]
-        project_name = gcloud_credentials_project_name or anyscale_cloud_project_name
+        project_name = default_credentials_project_name or anyscale_cloud_project_name
         if not yes:
-            if gcloud_credentials_project_name == anyscale_cloud_project_name:
+            if default_credentials_project_name == anyscale_cloud_project_name:
                 prompt_str = (
                     "Your current GCloud credentials and the GCP Project associated "
-                    f"with Anyscale Cloud {cloud.name} are for {gcloud_credentials_project_name}"
+                    f"with Anyscale Cloud {cloud.name} are for {default_credentials_project_name}"
                 )
             else:
                 prompt_str = (
                     "Your current GCloud credentials "
                     + (
-                        f"are for project {gcloud_credentials_project_name}."
-                        if gcloud_credentials_project_name
+                        f"are for project {default_credentials_project_name}."
+                        if default_credentials_project_name
                         else "do not contain a project."
                     )
                     + f"\nThe GCP Project associated with Anyscale Cloud {cloud.name} is {anyscale_cloud_project_name}."
@@ -789,6 +793,10 @@ class CloudController(BaseController):
                 default=project_name,
             )
 
+        discovery = try_import_gcp_discovery()
+        projects_client = discovery.build(
+            "cloudresourcemanager", "v3", credentials=credentials
+        ).projects()
         current_policy = projects_client.getIamPolicy(
             resource=f"projects/{project_name}"
         ).execute()
@@ -919,7 +927,7 @@ class CloudController(BaseController):
             )
             return False
 
-    def verify_aws_cloud_resources(  # noqa: PLR0913
+    def verify_aws_cloud_resources(
         self,
         cloud_resource: CreateCloudResource,
         boto3_session: boto3.Session,
@@ -1010,6 +1018,7 @@ class CloudController(BaseController):
         security_group_ids: List[str],
         s3_bucket_id: str,
         private_network: bool,
+        cluster_management_stack_version: ClusterManagementStackVersions,
     ):
         # Create a cloud without cloud resources first
         try:
@@ -1021,6 +1030,7 @@ class CloudController(BaseController):
                     name=name,
                     is_bring_your_own_resource=True,
                     is_private_cloud=private_network,
+                    cluster_management_stack_version=cluster_management_stack_version,
                 )
             )
             cloud_id = created_cloud.result.id
@@ -1075,12 +1085,6 @@ class CloudController(BaseController):
                 create_cloud_resource = associate_subnets_with_azs(
                     create_cloud_resource, region
                 )
-                # We are only taking the first security group in the list for now
-                # We also only verify the first security group and warn about multiple security groups in verify_aws_security_groups
-                create_cloud_resource.aws_security_groups = [
-                    create_cloud_resource.aws_security_groups[0]
-                ]
-
                 # update cloud with verified cloud resources
                 self.api_client.update_cloud_with_cloud_resource_api_v2_clouds_with_cloud_resource_router_cloud_id_put(
                     cloud_id=cloud_id,
