@@ -98,7 +98,7 @@ class CreateClusterComputeConfigModel(BaseModel):
     )
 
     @root_validator
-    def fill_cloud_id(cls: Any, values: Any) -> Any:  # noqa: N805
+    def fill_cloud_id(cls: Any, values: Any) -> Any:
         cloud_id, cloud = (
             values.get("cloud_id"),
             values.get("cloud"),
