@@ -423,7 +423,7 @@ class ClusterController(BaseController):
         ).result
         return cluster_env, build
 
-    def _get_cluster_compute(  # noqa: PLR0913
+    def _get_cluster_compute(
         self,
         cluster_compute_name: Optional[str],
         cluster_compute_file: Optional[str],
@@ -525,7 +525,7 @@ class ClusterController(BaseController):
 
         return (cluster, needs_start)
 
-    def _check_needs_start(  # noqa: PLR0913
+    def _check_needs_start(
         self,
         current_cluster: Cluster,
         build: ClusterEnvironmentBuild,
