@@ -277,7 +277,7 @@ class BaseHAJobConfig(BaseModel):
     )
 
     @root_validator
-    def fill_project_id(cls: Any, values: Any) -> Any:  # noqa: N805
+    def fill_project_id(cls: Any, values: Any) -> Any:
         project_id, project_name = (
             values.get("project_id"),
             values.get("project"),
@@ -296,7 +296,7 @@ class BaseHAJobConfig(BaseModel):
         return values
 
     @root_validator
-    def fill_cluster_env_from_custom_docker(cls: Any, values: Any) -> Any:  # noqa: N805
+    def fill_cluster_env_from_custom_docker(cls: Any, values: Any) -> Any:
         docker, python_version, ray_version, cluster_env, build_id = (
             values.get("docker"),
             values.get("python_version"),
@@ -334,7 +334,7 @@ class BaseHAJobConfig(BaseModel):
         return values
 
     @root_validator
-    def fill_build_id(cls: Any, values: Any) -> Any:  # noqa: N805
+    def fill_build_id(cls: Any, values: Any) -> Any:
         build_id, cluster_env = (
             values.get("build_id"),
             values.get("cluster_env"),
@@ -356,7 +356,7 @@ class BaseHAJobConfig(BaseModel):
         return values
 
     @root_validator
-    def fill_compute_config_id(cls: Any, values: Any) -> Any:  # noqa: N805
+    def fill_compute_config_id(cls: Any, values: Any) -> Any:
         compute_config_id, compute_config, cloud = (
             values.get("compute_config_id"),
             values.get("compute_config"),
@@ -387,7 +387,7 @@ class BaseHAJobConfig(BaseModel):
         return values
 
     @root_validator
-    def validate_runtime_env(cls: Any, values: Any) -> Any:  # noqa: N805, PLR0912
+    def validate_runtime_env(cls: Any, values: Any) -> Any:  # noqa: PLR0912
         runtime_env = values.get("runtime_env")
         if runtime_env is not None:
             if "conda" in runtime_env:
@@ -471,7 +471,7 @@ class LogProvider(ABC):
     def __enter__(self, *args, **kwargs):  # noqa: B027
         pass
 
-    def __exit__(self, *args, **kwargs):  # noqa: ARG002
+    def __exit__(self, *args, **kwargs):
         self.close()
 
 
@@ -488,7 +488,7 @@ class LokiLogProvider(LogProvider):
             "direction": "forward",
         }
 
-    def __enter__(self, *args, **kwargs):  # noqa: ARG002
+    def __enter__(self, *args, **kwargs):
         self.session = requests.Session()
         self.session.mount(
             "https://",
@@ -501,7 +501,7 @@ class LokiLogProvider(LogProvider):
     def close(self) -> None:
         self.session.close()
 
-    def __exit__(self, *args, **kwargs):  # noqa: ARG002
+    def __exit__(self, *args, **kwargs):
         self.close()
 
     def query(
@@ -545,7 +545,7 @@ class JobController(BaseController):
         self.log.open_block("Output")
         self.logs_controller = LogsController()
 
-    def submit(  # noqa: PLR0913
+    def submit(
         self,
         job_config_file: str,
         name: Optional[str] = None,
@@ -678,7 +678,7 @@ class JobController(BaseController):
             config_dict = yaml.safe_load(f)
         return config_dict
 
-    def wait(  # noqa: PLR0913
+    def wait(
         self,
         job_name: Optional[str] = None,
         job_id: Optional[str] = None,
@@ -769,7 +769,7 @@ class JobController(BaseController):
                 if job.last_job_run and job.last_job_run.cluster
                 else None,
                 "Current state": job.state.current_state,
-                "Creator": job.creator.username,
+                "Creator": job.creator.email,
                 "Entrypoint": job.config.entrypoint
                 if len(job.config.entrypoint) < 100
                 else job.config.entrypoint[:100] + " ...",
@@ -827,7 +827,7 @@ class JobController(BaseController):
                 if job.last_job_run and job.last_job_run.cluster
                 else None,
                 job.state.current_state,
-                job.creator.username,
+                job.creator.email,
                 job.config.entrypoint
                 if len(job.config.entrypoint) < 50
                 else job.config.entrypoint[:50] + " ...",
