@@ -226,11 +226,11 @@ class ScheduleController(BaseController):
         self.url(id)
         self.log.info(f"Successfully created Job with id {created_job.id}")
         url = self.endpoint_formatter.get_job_endpoint(created_job.id)
-        self.log.info(f"View your Production Job at {url}.")
+        self.log.info(f"View your Production Job at {url}")
 
     def url(self, id) -> str:  # noqa: A002
         url = self.endpoint_formatter.get_schedule_endpoint(id)
-        self.log.info(f"View your schedule at {url}.")
+        self.log.info(f"View your schedule at {url}")
         return url
 
 
