@@ -2,10 +2,14 @@ import os
 from typing import Any, Dict, List, Optional
 
 import click
+import tabulate
 import yaml
 
 from anyscale.cli_logger import BlockLogger
 from anyscale.client.openapi_client import ComputeTemplate, ProductionJob
+from anyscale.client.openapi_client.models.decorated_list_service_api_model import (
+    DecoratedListServiceAPIModel,
+)
 from anyscale.controllers.base_controller import BaseController
 from anyscale.controllers.job_controller import JobController
 from anyscale.formatters.service_formatter import (
@@ -14,6 +18,7 @@ from anyscale.formatters.service_formatter import (
 )
 from anyscale.models.service_model import ServiceConfig
 from anyscale.project import infer_project_id
+from anyscale.tables import ServicesTable
 from anyscale.util import get_endpoint, is_anyscale_workspace
 from anyscale.utils.runtime_env import override_runtime_env_for_local_working_dir
 
@@ -35,23 +40,55 @@ class ServiceController(BaseController):
             initialize_auth_api_client=initialize_auth_api_client
         )
 
+    def _get_services_by_name(
+        self,
+        *,
+        name: Optional[str] = None,
+        project_id: Optional[str] = None,
+        created_by_me: bool,
+        max_items: int,
+    ) -> List[DecoratedListServiceAPIModel]:
+        """Makes an API call to get all services matching the provided filters.
+
+        This returns both v1 and v2 services.
+        """
+        creator_id = None
+        if created_by_me:
+            user_info_response = self.api_client.get_user_info_api_v2_userinfo_get()
+            creator_id = user_info_response.result.id
+
+        services_list = []
+        resp = self.api_client.list_services_api_v2_services_v2_get(
+            project_id=project_id, name=name, creator_id=creator_id, count=10,
+        )
+        services_list.extend(resp.results)
+        paging_token = resp.metadata.next_paging_token
+        while paging_token is not None and len(services_list) < max_items:
+            resp = self.api_client.list_services_api_v2_services_v2_get(
+                project_id=project_id,
+                name=name,
+                creator_id=creator_id,
+                count=10,
+                paging_token=paging_token,
+            )
+            services_list.extend(resp.results)
+            paging_token = resp.metadata.next_paging_token
+
+        return services_list[:max_items]
+
     def _get_service_id_from_name(
         self, service_name: str, project_id: Optional[str]
     ) -> str:
         """Get the ID for a service by name.
 
-        If project_id is specified, filter to that project, else use the default infer_project_id logic.
+        If project_id is specified, filter to that project, else don't filter on project_id and
+        instead error if there are multiple services with the name.
 
         Raises an exception if there are zero or multiple services with the given name.
         """
-        if project_id is None:
-            project_id = infer_project_id(
-                project_id, self.anyscale_api_client, self.log
-            )
-
-        results = self.api_client.list_services_api_v2_services_v2_get(
-            project_id=project_id, name=service_name,
-        ).results
+        results = self._get_services_by_name(
+            name=service_name, project_id=project_id, created_by_me=False, max_items=10
+        )
 
         if len(results) == 0:
             raise click.ClickException(
@@ -61,16 +98,19 @@ class ServiceController(BaseController):
         elif len(results) > 1:
             raise click.ClickException(
                 f"There are multiple services with name '{service_name}'. "
-                "Please specify the --service-id instead."
+                "Please filter using --project-id or specify the --service-id instead. "
+                f"Services found: \n{ServicesTable(results)}"
             )
 
         return results[0].id
 
     def get_service_id(
         self,
-        service_id: Optional[str],
-        service_name: Optional[str],
-        service_config_file: Optional[str],
+        *,
+        service_id: Optional[str] = None,
+        service_name: Optional[str] = None,
+        service_config_file: Optional[str] = None,
+        project_id: Optional[str] = None,
     ) -> str:
         """Get the service ID given the ID, name, or config file.
 
@@ -79,8 +119,9 @@ class ServiceController(BaseController):
 
         The precedence is: service_id > service_name > service_config_file.
 
-        If the service_config_file is provided and it has a project_id, that will be used to
-        filter the query. Else this uses the infer_project_id default logic.
+        If the project_id is specified directly or via the service_config_file it will be used
+        to filter the query. Else we will try to find the service across all projects and error
+        if there are multiple.
         """
         if service_id is not None:
             if service_name is not None or service_config_file is not None:
@@ -92,14 +133,14 @@ class ServiceController(BaseController):
                 raise click.ClickException(
                     "Only one of service ID, name, or config file should be specified."
                 )
-            service_id = self._get_service_id_from_name(service_name, None)
+            service_id = self._get_service_id_from_name(service_name, project_id)
         elif service_config_file is not None:
             service_config: ServiceConfig = self._read_service_config_file(
                 service_config_file
             )
-            service_id = self._get_service_id_from_name(
-                service_config.name, service_config.project_id
-            )
+            # Allow the passed project_id to override the one in the file.
+            project_id = project_id or service_config.project_id
+            service_id = self._get_service_id_from_name(service_config.name, project_id)
         else:
             raise click.ClickException(
                 "Service ID, name, or config file must be specified."
@@ -107,11 +148,11 @@ class ServiceController(BaseController):
 
         return service_id
 
-    def deploy(  # noqa: PLR0913
+    def deploy(
         self,
         service_config_file: str,
-        name: Optional[str],
-        description: Optional[str],
+        name: Optional[str] = None,
+        description: Optional[str] = None,
         healthcheck_url: Optional[str] = None,
         is_entrypoint_cmd: Optional[bool] = False,
         entrypoint: Optional[List[str]] = None,
@@ -120,7 +161,10 @@ class ServiceController(BaseController):
         if is_anyscale_workspace() and is_entrypoint_cmd:
             entrypoint = [service_config_file, *entrypoint]
             config = self.generate_config_from_entrypoint(
-                entrypoint, name, description, healthcheck_url=healthcheck_url
+                entrypoint,
+                name=name,
+                description=description,
+                healthcheck_url=healthcheck_url,
             )
             project_id = infer_project_id(
                 config.project_id, self.anyscale_api_client, self.log
@@ -134,8 +178,12 @@ class ServiceController(BaseController):
         elif len(entrypoint) == 0:
             # Assume that service_config_file is a file and submit it.
             config = self.generate_config_from_file(
-                service_config_file, name, description, healthcheck_url=healthcheck_url,
+                service_config_file,
+                name=name,
+                description=description,
+                healthcheck_url=healthcheck_url,
             )
+
             project_id = infer_project_id(
                 config.project_id, self.anyscale_api_client, self.log
             )
@@ -156,8 +204,8 @@ class ServiceController(BaseController):
     def generate_config_from_entrypoint(
         self,
         entrypoint: List[str],
-        name: Optional[str],
-        description: Optional[str],
+        name: Optional[str] = None,
+        description: Optional[str] = None,
         healthcheck_url: Optional[str] = "/healthcheck",
     ) -> ServiceConfig:
         config_dict = {
@@ -171,11 +219,13 @@ class ServiceController(BaseController):
     def generate_config_from_file(
         self,
         service_config_file,
+        *,
         name: Optional[str] = None,
         description: Optional[str] = None,
         healthcheck_url: Optional[str] = None,
         version: Optional[str] = None,
         canary_percent: Optional[int] = None,
+        rollout_strategy: Optional[str] = None,
     ) -> ServiceConfig:
         service_config: ServiceConfig = self._read_service_config_file(
             service_config_file
@@ -195,6 +245,12 @@ class ServiceController(BaseController):
         if canary_percent:
             service_config.canary_weight = canary_percent
 
+        if rollout_strategy:
+            service_config.rollout_strategy = rollout_strategy
+
+        if service_config.rollout_strategy:
+            service_config.rollout_strategy = service_config.rollout_strategy.upper()
+
         return service_config
 
     def deploy_from_config(self, service_config: ServiceConfig):
@@ -282,6 +338,7 @@ class ServiceController(BaseController):
         name: Optional[str] = None,
         version: Optional[str] = None,
         canary_percent: Optional[int] = None,
+        rollout_strategy: Optional[str] = None,
     ):
         """
         Deploys a Service 2.0.
@@ -291,6 +348,7 @@ class ServiceController(BaseController):
             name=name,
             version=version,
             canary_percent=canary_percent,
+            rollout_strategy=rollout_strategy,
         )
         config.runtime_env = override_runtime_env_for_local_working_dir(
             config.runtime_env
@@ -307,24 +365,101 @@ class ServiceController(BaseController):
             f'View the service in the UI at {get_endpoint(f"/services/{service.id}")}.'
         )
 
-    def list(  # noqa: PLR0913
+    def list(
         self,
-        include_all_users: bool,
-        include_archived: bool,
-        name: Optional[str],
-        service_id: Optional[str],
-        project_id: Optional[str],
-        max_items: int,
+        *,
+        name: Optional[str] = None,
+        service_id: Optional[str] = None,
+        project_id: Optional[str] = None,
+        created_by_me: bool = False,
+        max_items: int = 10,
     ) -> None:
-        self.job_controller.list(
-            include_all_users,
-            name,
-            service_id,
-            project_id,
-            include_archived=include_archived,
-            max_items=max_items,
-            is_service=True,
+        try:
+            self._list_via_service_list_endpoint(
+                name=name,
+                service_id=service_id,
+                project_id=project_id,
+                created_by_me=created_by_me,
+                max_items=max_items,
+            )
+        except Exception as e:  # noqa: BLE001
+            if "Services v2 is not enabled for your organization." in str(e):
+                # An exception will be thrown if the "services_v2_enable_all_features" flag is not enabled
+                # Therefore, we default to showing only Service v1.
+                # TODO: shawnp. Remove the exception logic once we enable service v2 flag for all customers
+                self.job_controller.list(
+                    name=name,
+                    job_id=service_id,
+                    project_id=project_id,
+                    include_all_users=not created_by_me,
+                    include_archived=False,
+                    max_items=max_items,
+                    is_service=True,
+                )
+            else:
+                self.log.info(
+                    "We are unable to get a list of Services."
+                    "This is unexpected and please contact Anyscale support for more info."
+                )
+
+    def _list_via_service_list_endpoint(
+        self,
+        *,
+        name: Optional[str] = None,
+        service_id: Optional[str] = None,
+        project_id: Optional[str] = None,
+        created_by_me: bool = False,
+        max_items: int,
+    ):
+        services = []
+        if service_id:
+            if _is_v2_service_id(service_id):
+                service = self.api_client.get_service_api_v2_services_v2_service_id_get(
+                    service_id
+                ).result
+                services.append(service)
+            else:
+                service = self.api_client.get_job_api_v2_decorated_ha_jobs_production_job_id_get(
+                    service_id
+                ).result
+                # We short-circuit if service v1 if the model is different from service v2
+                service_v1_res = [
+                    [
+                        service.name,
+                        service.id,
+                        service.state.current_state,
+                        service.creator.email,
+                    ]
+                ]
+
+                table = tabulate.tabulate(
+                    service_v1_res,
+                    headers=["NAME", "ID", "CURRENT STATE", "CREATOR"],
+                    tablefmt="plain",
+                )
+                self.log.info(
+                    f'View your Services in the UI at {get_endpoint("/services")}'
+                )
+                self.log.info(f"Services:\n{table}")
+                return
+        else:
+            services = self._get_services_by_name(
+                name=name,
+                project_id=project_id,
+                created_by_me=created_by_me,
+                max_items=max_items,
+            )
+
+        # TODO: shawnp. Add creator username once that's exposed
+        services_table = [
+            [service.name, service.id, service.current_state,] for service in services
+        ]
+
+        table = tabulate.tabulate(
+            services_table, headers=["NAME", "ID", "CURRENT STATE"], tablefmt="plain",
         )
+        self.log.info(f'View your Services in the UI at {get_endpoint("/services")}')
+        self.log.info(f"Services:\n{table}")
 
     def archive(self, service_id: str):
         if _is_v2_service_id(service_id):
