@@ -1,4 +1,3 @@
-from datetime import datetime
 import json
 import os
 from os import path
@@ -41,6 +40,7 @@ from anyscale.utils.aws_credentials_util import (
 )
 from anyscale.utils.env_utils import set_env
 from anyscale.utils.imports.all import try_import_ray
+from anyscale.utils.name_utils import gen_valid_name
 
 
 def get_head_node_ip(cluster_config: Union[Dict[str, Any], str]) -> Any:
@@ -107,7 +107,7 @@ class SessionController(BaseController):
             f"Session {session_names_str} shutting down. View progress at {url}"
         )
 
-    def start(  # noqa: PLR0913
+    def start(
         self,
         session_name: Optional[str],
         build_id: Optional[str],
@@ -157,7 +157,7 @@ class SessionController(BaseController):
         url = get_endpoint(f"/projects/{project_id}/clusters/{session.id}")
         print(f"Session {session_name} finished starting. View at {url}")
 
-    def ssh(  # noqa: PLR0912, PLR0913, PLR0915
+    def ssh(  # noqa: PLR0912, PLR0913
         self,
         session_name: str,
         ssh_option: Sequence[str],
@@ -289,9 +289,9 @@ class SessionController(BaseController):
                     [f"docker exec -it {container_name} sh -c  {ssh_from_head_command}"]
                 )
 
-        subprocess.run(ssh_command)  # noqa: B1
+        subprocess.run(ssh_command)
 
-    def pull(  # noqa: PLR0913
+    def pull(
         self,
         session_name: Optional[str] = None,
         source: Optional[str] = None,
@@ -351,7 +351,7 @@ class SessionController(BaseController):
             print(e)
             raise click.ClickException(str(e))  # type: ignore
 
-    def push(  # noqa: PLR0913
+    def push(
         self,
         session_name: Optional[str],
         source: Optional[str],
@@ -433,7 +433,7 @@ class SessionController(BaseController):
         config_object = ComputeTemplateConfig(**config_dict)
         created_template = self.api_client.create_compute_template_api_v2_compute_templates_post(
             create_compute_template=CreateComputeTemplate(
-                name=f"autogenerated-config-{datetime.now().isoformat()}",
+                name=gen_valid_name("autogenerated-config"),
                 project_id=project_id,
                 config=config_object,
             )
@@ -441,7 +441,7 @@ class SessionController(BaseController):
         compute_template_id = str(created_template.id)
         return compute_template_id
 
-    def _create_or_update_session_data(  # noqa: PLR0913
+    def _create_or_update_session_data(
         self,
         session_name: str,
         project_id: str,
