@@ -1,7 +1,7 @@
 import os
 import shlex
 import subprocess
-from typing import Any, Dict, List, Optional, Sequence
+from typing import Any, Dict, List, Optional
 
 from pydantic import BaseModel
 
@@ -11,18 +11,24 @@ from anyscale.client.openapi_client.models.experimental_workspace import (
 )
 from anyscale.cluster_config import configure_for_session
 from anyscale.controllers.base_controller import BaseController
-from anyscale.sdk.anyscale_client.models.cloud_version import CloudVersion
-from anyscale.shared_anyscale_utils.conf import V2_RAY_MOUNT_PATH
 from anyscale.util import get_working_dir
-from anyscale.utils.imports.all import try_import_ray
 from anyscale.workspace import load_workspace_id_or_throw, write_workspace_id_to_disk
 
 
+ANYSCALE_WORKSPACES_SSH_OPTIONS = [
+    "-o",
+    "StrictHostKeyChecking=no",
+    "-o",
+    "UserKnownHostsFile=/dev/null",
+    "-o",
+    "IdentitiesOnly=yes",
+]
+
+
 class WorkspaceCommandContext(BaseModel):
     cluster_config: Dict[str, Any]
     head_ip: str
     project_id: str
-    cluster_id: str
 
 
 class WorkspaceController(BaseController):
@@ -73,13 +79,10 @@ class WorkspaceController(BaseController):
         ).result.head_ip
 
         return WorkspaceCommandContext(
-            cluster_config=cluster_config,
-            head_ip=head_ip,
-            project_id=project_id,
-            cluster_id=cluster_id,
+            cluster_config=cluster_config, head_ip=head_ip, project_id=project_id,
         )
 
-    def run_cmd(self, ssh_option: Sequence[str], cmd: str):
+    def run_cmd(self, cmd: str):
         workspace_command_context = self._get_workspace_command_context()
         cluster_config = workspace_command_context.cluster_config
 
@@ -93,48 +96,48 @@ class WorkspaceController(BaseController):
 
         ssh_command = (
             ["ssh"]
-            + list(ssh_option)
+            + ANYSCALE_WORKSPACES_SSH_OPTIONS
             + ["-o", f"ProxyCommand=ssh -W %h:%p -i {key_path} {target_host}"]
             + ["-tt", "-i", key_path]
             + ["ray@0.0.0.0", "-p", "5020"]
             + [f"sh -c {command}"]
         )
 
-        subprocess.run(ssh_command)  # noqa: B1
+        subprocess.run(ssh_command)
 
     def run_rsync(
         self,
-        ssh_option: Sequence[str],
         local_path: str,
         *,
         down: bool,
         rsync_filters: List[str],
         rsync_excludes: List[str],
     ) -> None:
-        try_import_ray()
-        from ray.autoscaler.sdk import get_docker_host_mount_location
-
         workspace_command_context = self._get_workspace_command_context()
         cluster_config = workspace_command_context.cluster_config
         head_ip = workspace_command_context.head_ip
         project_id = workspace_command_context.project_id
-        cluster_id = workspace_command_context.cluster_id
 
-        ssh_user = cluster_config["auth"]["ssh_user"]
-        key_path = cluster_config["auth"]["ssh_private_key"]
+        ssh_user: str = cluster_config["auth"]["ssh_user"]
+        key_path: str = cluster_config["auth"]["ssh_private_key"]
 
-        base_ssh_command = ["ssh"] + ["-i", key_path] + list(ssh_option)
+        identity_file_option = ["-i", key_path]
+        proxy_thorugh_ssh_user_option = [
+            "-o",
+            f"ProxyCommand=ssh -W %h:%p -i {key_path} {ssh_user}@{head_ip}",
+        ]
+        ray_user_ssh_port_option = ["-p", "5020"]
+        base_ssh_command = (
+            ["ssh"]
+            + identity_file_option
+            + ANYSCALE_WORKSPACES_SSH_OPTIONS
+            + proxy_thorugh_ssh_user_option
+            + ray_user_ssh_port_option
+        )
 
-        directory_name = get_working_dir(cluster_config, project_id, self.api_client)
-
-        cloud_id = self.anyscale_api_client.get_session(cluster_id).result.cloud_id
-        cloud_version = self.anyscale_api_client.get_cloud(cloud_id).result.version
-        mount_path = (
-            V2_RAY_MOUNT_PATH
-            if not cloud_version or cloud_version == CloudVersion.V2
-            else get_docker_host_mount_location(cluster_config["cluster_name"])
+        source_directory = (
+            get_working_dir(cluster_config, project_id, self.api_client) + "/"
         )
-        source_directory = mount_path + directory_name + "/"
 
         rsync_command = [
             "rsync",
@@ -150,15 +153,22 @@ class WorkspaceController(BaseController):
         for rsync_filter in rsync_filters:
             rsync_command.extend(["--filter", f"dir-merge,- {rsync_filter}"])
 
+        # TODO: Perhaps include this in cluster_config somewhere so that below isn't hardcoded
+        # if either the user or host for the ray container is changed in the future
+        ray_user_on_host = "ray@0.0.0.0"
+        source_directory = (
+            get_working_dir(cluster_config, project_id, self.api_client) + "/"
+        )
+
         if down:
             rsync_command += [
-                f"{ssh_user}@{head_ip}:{source_directory}",
+                f"{ray_user_on_host}:{source_directory}",
                 local_path,
             ]
         else:
             rsync_command += [
                 local_path,
-                f"{ssh_user}@{head_ip}:{source_directory}",
+                f"{ray_user_on_host}:{source_directory}",
             ]
 
-        subprocess.run(rsync_command)  # noqa: B1
+        subprocess.run(rsync_command)
