@@ -56,6 +56,18 @@ class ServiceConfig(BaseHAJobConfig):
         "and the existing version will have `100 - canary_weight`.",
     )
 
+    rollout_strategy: Optional[str] = Field(
+        None,
+        description="Strategy for rollout. "
+        "The ROLLOUT strategy will deploy your Ray Serve configuration onto a newly started cluster, and then shift traffic over to the new cluster. "
+        "You can manually control the speed of the rollout using the canary_weight configuration.\n"
+        "The IN_PLACE strategy will use Ray Serve in place upgrade to update your existing cluster in place. "
+        "When using this rollout strategy, you may only change the ray_serve_config field. "
+        "You cannot partially shift traffic or rollback an in place upgrade. "
+        "In place upgrades are faster and riskier than rollouts, and we recommend only using them for relatively safe changes (for example, increasing the number of replicas on a Ray Serve deployment).\n"
+        "Default strategy is ROLLOUT.",
+    )
+
     @root_validator
     def validates_config(cls, values) -> Dict[str, Any]:
         # entrypoint is used for Services V1 and serve config for Services V2
