@@ -1,9 +1,16 @@
+import asyncio
+import contextlib
 import os
 import sys
 from time import sleep, time
-from typing import Any, Dict, Optional, Union
+from typing import Any, Callable, Dict, List, Optional, Union
+import warnings
 
 from anyscale.api import configure_tcp_keepalive
+from anyscale.api_utils.job_logs_util import _get_logs_from_running_production_job, _get_job_logs_from_storage_bucket, _get_logs_from_running_job
+from anyscale.api_utils.job_util import _is_job_on_v2_cloud, _is_production_job_on_v2_cloud
+from anyscale.api_utils.exceptions.log_retrieval_errors import ExpectedLogRetrievalError, LogRetrievalTimeoutError, UnsupportedLogRetrievalMethodError
+from anyscale.api_utils.logs_util import _remove_ansi_escape_sequences
 from anyscale.sdk.anyscale_client.models.cluster_compute_config import (
     ClusterComputeConfig,
 )
@@ -14,6 +21,7 @@ from anyscale.utils.runtime_env import upload_and_rewrite_working_dir
 from anyscale.sdk import anyscale_client
 from anyscale.sdk.anyscale_client.api.default_api import DefaultApi
 from anyscale.version import __version__ as version
+from anyscale.sdk.anyscale_client.models.cloud import Cloud
 from anyscale.sdk.anyscale_client.models.create_cluster_environment import (
     CreateClusterEnvironment,
 )
@@ -21,9 +29,12 @@ from anyscale.sdk.anyscale_client.models.create_byod_cluster_environment import
     CreateBYODClusterEnvironment,
 )
 from anyscale.sdk.anyscale_client.models.cluster import Cluster
+from anyscale.sdk.anyscale_client.models.session import Session
 from anyscale.sdk.anyscale_client.models.cluster_environment_build import (
     ClusterEnvironmentBuild,
 )
+from anyscale.sdk.anyscale_client.models.job import Job
+from anyscale.sdk.anyscale_client.models.jobslogs_response import JobslogsResponse
 from anyscale.shared_anyscale_utils.headers import RequestHeaders
 from anyscale.cli_logger import BlockLogger
 from anyscale.util import get_endpoint
@@ -400,6 +411,37 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
             return self.get_cluster(operation.cluster_id).result
 
     def fetch_job_logs(self, job_id: str) -> str:
+        """
+        Retrieves logs for a job run (eg. 'job_123').
+        
+        This will try in following order until it finds a retrieval method that returns the logs:
+        1. Ray Dashboard API on the cluster that the job run is on
+           NOTE: The caller of this function must be able to reach the Ray dashboard host.
+        2. (only for anyscale v1 clouds) Anyscale backend / cache layer which stores logs for recently finished job runs
+        3. The storage bucket for the Anyscale cloud the job run (and its cluster) is on
+
+        Args:
+            job_id (str): ID of a job run
+
+        Returns:
+            str: All logs for the job run
+                (so far, if the job run is still running)
+        """
+        get_job_logs_fns: List[Callable[..., str]] = [
+            lambda: asyncio.run(_get_logs_from_running_job(self, job_id)),
+            lambda: self._fetch_job_logs_legacy(job_id),
+            lambda: asyncio.run(_get_job_logs_from_storage_bucket(self, job_run_id=job_id)),
+        ]
+        logs = ""
+        # Return logs from the first retrieval method that has non-empty logs
+        for fn in get_job_logs_fns:
+            with contextlib.suppress(ExpectedLogRetrievalError):
+                logs = fn()
+                if logs:
+                    return logs
+        return logs    
+
+    def _fetch_job_logs_legacy(self, job_id: str) -> str:
         """
         Retrieves logs for a Ray Job or Interactive Session.
         This function may take several minutes if the Cluster this Job ran on has been terminated.
@@ -411,8 +453,19 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
             Log output for the Job as a string
 
         Raises
+            UnsupportedLogRetrievalMethodError if on an Anyscale v2 cloud
             Exception if we fail to fetch logs
         """
+        if _is_job_on_v2_cloud(self, job_id):
+            raise UnsupportedLogRetrievalMethodError(
+                "Logs are not stored Anyscale-side on clouds set up with Anyscale v2."
+            )
+        else:
+            warnings.warn(
+                "Fetching logs stored in Anyscale backend is deprecated. "
+                "Please consider moving to a cloud set up with Anyscale v2.",
+                DeprecationWarning
+            )
 
         # Timeout in 5 minutes
         timeout = time() + 300
@@ -421,14 +474,15 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
 
         while not logs.ready:
             if time() > timeout:
-                raise Exception(f"Failed to get logs from Job {job_id}")
+                raise LogRetrievalTimeoutError(f"Failed to get logs from Job {job_id}")
 
             sleep(15)
             logs = self.get_job_logs(job_id).result
 
-        return str(logs.logs)
+        # Logs will be empty if on anyscale v1 and job logs are no longer in cache
+        return _remove_ansi_escape_sequences(logs.logs)
 
-    def get_production_job_logs(self, job_id: str) -> str:
+    def get_production_job_logs(self, job_id: str) -> JobslogsResponse:
         """
         Retrieves logs for latest run of a Production Job.
 
@@ -436,7 +490,7 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
             job_id - ID of the Job
 
         Returns
-            Log output for the Job as a string
+            Response containing the log output for the job
 
         Raises
             Exception if we fail to fetch logs
@@ -451,6 +505,38 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
         return self.get_job_logs(latest_job_run_id)
 
     def fetch_production_job_logs(self, job_id: str) -> str:
+        """
+        Retrieves logs for a job (eg. 'prodjob_123').
+        - This will retrieve logs from only the latest job run of the job.
+
+        This will try in following order until it finds a retrieval method that returns the logs:
+        1. Ray Dashboard API on the cluster that the job is running on
+           NOTE: The caller of this function must be able to reach the Ray dashboard host.
+        2. (only for anyscale v1 clouds) Anyscale backend / cache layer which stores logs for recently finished jobs
+        3. The storage bucket for the Anyscale cloud the job (and its cluster) is running on
+
+        Args:
+            job_id (str): ID of a job
+
+        Returns:
+            str: All logs for the job
+                (so far, if the job is still running)
+        """
+        get_job_logs_fns: List[Callable[..., str]] = [
+            lambda: asyncio.run(_get_logs_from_running_production_job(self, job_id)),
+            lambda: self._fetch_production_job_logs_legacy(job_id),
+            lambda: asyncio.run(_get_job_logs_from_storage_bucket(self, job_id=job_id)),
+        ]
+        logs = ""
+        # Return logs from the first retrieval method that has non-empty logs
+        for fn in get_job_logs_fns:
+            with contextlib.suppress(ExpectedLogRetrievalError):
+                logs = fn()
+                if logs:
+                    return logs
+        return logs
+
+    def _fetch_production_job_logs_legacy(self, job_id: str) -> str:
         """
         Retrieves logs for latest run of a Production Job.
         Waits 5 min for logs to be ready.
@@ -463,8 +549,19 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
             Log output for the Job as a string
 
         Raises
+            UnsupportedLogRetrievalMethodError if on an Anyscale v2 cloud
             Exception if we fail to fetch logs
         """
+        if _is_production_job_on_v2_cloud(self, job_id):
+            raise UnsupportedLogRetrievalMethodError(
+                "Logs are not stored Anyscale-side on clouds set up with Anyscale v2."
+            )
+        else:
+            warnings.warn(
+                "Fetching logs stored in Anyscale backend is deprecated. "
+                "Please consider moving to a cloud set up with Anyscale v2.",
+                DeprecationWarning
+            )
 
         # Timeout in 5 minutes
         timeout = time() + 300
@@ -478,7 +575,8 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
             sleep(15)
             logs = self.get_production_job_logs(job_id).result
 
-        return str(logs.logs)
+        # Logs will be empty if on anyscale v1 and job logs are no longer in cache        
+        return _remove_ansi_escape_sequences(logs.logs)
 
     def create_job(self, create_production_job, **kwargs):
         _upload_and_rewrite_working_dir_in_create_production_job(create_production_job)
