@@ -28,6 +28,7 @@ CONFIGS_TO_REPLICATE = [
     ".workspacerc",
     ".gitconfig",
     ".vimrc",
+    ".tmux.conf",
 ]
 
 # Default cluster storage dir.
@@ -98,11 +99,11 @@ def optimize_git_repo(directory: str, shared_repo: str) -> None:
             os.makedirs(os.path.dirname(shared_repo), exist_ok=True)
             # TODO(ekl) it's faster to do a copy of just the objects dir, but it seems
             # we need to git clone in order for alternates to be recognized as valid.
-            subprocess.check_call(  # noqa
+            subprocess.check_call(
                 f"git clone --bare {directory}/ {shared_repo}/", shell=True,
             )
         shared_objects_dir = os.path.join(shared_repo, "objects")
-        subprocess.check_call(  # noqa
+        subprocess.check_call(
             f"rsync -a {objects_path}/ {shared_objects_dir}/", shell=True
         )
         subprocess.check_call("rm -rf {}".format(objects_path), shell=True)  # noqa
@@ -147,7 +148,7 @@ def create_snapshot_zip(directory: str, auto: bool) -> str:
     try:
         os.chdir(directory)
         if is_git_workspace and is_within_workspace:
-            subprocess.check_call(  # noqa
+            subprocess.check_call(
                 "(git ls-files -co --exclude-standard || true; find .git || true) | "
                 f"zip --symlinks -@ -0 -q {target}",
                 shell=True,
@@ -160,7 +161,7 @@ def create_snapshot_zip(directory: str, auto: bool) -> str:
                         "that your git repo is cloned in the top-level workspace "
                         f"directory with 'git clone <repo> .' at {directory}."
                     )
-            subprocess.check_call(  # noqa
+            subprocess.check_call(
                 f"find . | zip --symlinks -@ -0 -q {target}", shell=True,
             )
     finally:
@@ -185,9 +186,7 @@ def unpack_snapshot_zip(zip_path: str, directory: str) -> None:
 
     start = time.time()
     os.makedirs(directory, exist_ok=True)
-    subprocess.check_call(  # noqa
-        f"unzip -X -o -q {zip_path} -d {directory}", shell=True
-    )
+    subprocess.check_call(f"unzip -X -o -q {zip_path} -d {directory}", shell=True)
     logger.info(
         "Unpacked snapshot {} to {} in {}s.".format(
             zip_path, directory, time.time() - start
@@ -259,7 +258,7 @@ def unpack_github_dir(github_tree_uri: str, out_dir: str) -> None:
 
 def compute_content_hash(zip_path: str) -> bytes:
     """Return the md5 hash of a given zipfile on disk."""
-    md5 = subprocess.check_output(  # noqa
+    md5 = subprocess.check_output(
         f"unzip -p {zip_path} | md5sum -b | cut -f1 -d ' '", shell=True
     )
     md5 = md5.strip()
@@ -336,7 +335,7 @@ def do_snapshot(auto: bool = False):
         # report successful idle termination status
         report_idle_termination_activity()
 
-    except Exception:  # noqa: BLE001
+    except Exception:
         logger.exception("Failed to create a snapshot")
         # report error idle termination status
         report_idle_termination_error("Failed to create a snapshot")
@@ -390,7 +389,7 @@ def gc_snapshots() -> None:
             try:
                 os.unlink(full_path)
                 os.unlink(md5)
-            except Exception:  # noqa: BLE001
+            except Exception:
                 logger.exception("Failed to delete snapshot")
 
 
@@ -414,7 +413,7 @@ def find_base_snapshot() -> Optional[str]:  # noqa: PLR0911
         return None
     try:
         base_data = json.loads(BASE_SNAPSHOT)
-    except Exception:  # noqa: BLE001
+    except Exception:
         logger.exception("Failed to parse base snapshot info")
         return None
 
@@ -648,8 +647,8 @@ def setup_credentials():
 
     for cmd in setup_ssh_directory_cmds:
         try:
-            subprocess.check_call(cmd, shell=True)  # noqa
-        except Exception:  # noqa: BLE001
+            subprocess.check_call(cmd, shell=True)
+        except Exception:
             logger.exception(f"Error running {cmd}")
 
     if os.path.exists(private_key):
@@ -658,7 +657,7 @@ def setup_credentials():
         shutil.copy(public_key, "/home/ray/.ssh/id_rsa.pub")
     else:
         # Copy up to EFS.
-        subprocess.check_call(  # noqa
+        subprocess.check_call(
             "echo y | ssh-keygen -t rsa -f /home/ray/.ssh/id_rsa -N ''", shell=True
         )
         os.makedirs(os.path.dirname(private_key), exist_ok=True)
@@ -680,7 +679,7 @@ def _load_env_vars():
         try:
             with open(env_store) as f:
                 env_vars = json.loads(f.read())
-        except Exception:  # noqa: BLE001
+        except Exception:
             logger.exception("Error parsing env vars")
     return env_vars
 
@@ -732,8 +731,8 @@ def setup_nfs():
         COMMANDS.append(f"ln -sf /mnt/user_storage/{config} /home/ray/{config}")
     for cmd in COMMANDS:
         try:
-            subprocess.check_call(cmd, shell=True)  # noqa
-        except Exception:  # noqa: BLE001
+            subprocess.check_call(cmd, shell=True)
+        except Exception:
             logger.exception(f"Error running {cmd}")
 
     # on first load, report an activity to signal healthy start
@@ -775,7 +774,7 @@ def setup_container(ray_params: Any, is_head: bool):  # noqa: ARG001, PLR0912
     else:
         try:
             setup_nfs()
-        except Exception:  # noqa: BLE001
+        except Exception:
             logger.exception("Failed to setup NFS")
         if not WORKSPACE_ID:
             logger.info("No workspace id configured, skipping workspace restore.")
@@ -784,15 +783,15 @@ def setup_container(ray_params: Any, is_head: bool):  # noqa: ARG001, PLR0912
         else:
             try:
                 restore_latest()
-            except Exception:  # noqa: BLE001
+            except Exception:
                 logger.exception("Failed to restore workspace")
             try:
                 setup_credentials()
-            except Exception:  # noqa: BLE001
+            except Exception:
                 logger.exception("Failed to setup SSH credentials")
             try:
                 setup_vscode_desktop()
-            except Exception:  # noqa: BLE001
+            except Exception:
                 logger.exception("Failed to setup VSCode desktop")
     with open("/tmp/initialized", "w") as f:
         f.write("ok")
@@ -818,7 +817,7 @@ def post_build():
     ]
     for cmd in CMDS:
         print("Executing", cmd)
-        subprocess.check_call(cmd, shell=True)  # noqa
+        subprocess.check_call(cmd, shell=True)
 
 
 if __name__ == "__main__":
