@@ -250,7 +250,7 @@ def get_availability_zones(region: str) -> List[str]:
     ]
 
 
-def launch_gcp_cloud_setup(  # noqa: PLR0913
+def launch_gcp_cloud_setup(
     name: str,
     region: str,
     is_k8s: Optional[bool],
