@@ -272,7 +272,7 @@ def make_application(
     )
 
 
-def main(  # noqa: PLR0913
+def main(
     deploy_environment: str,
     use_debugger: bool,  # noqa: ARG001
     cli_token: str,
