@@ -8,7 +8,7 @@ from anyscale.project import ANYSCALE_PROJECT_FILE, find_project_root
 
 def write_workspace_id_to_disk(workspace_id: str, directory: str) -> None:
     with open(os.path.join(directory, ANYSCALE_PROJECT_FILE), "w") as f:
-        f.write("{}".format("workspace_id: {}".format(workspace_id)))
+        f.write("{}".format(f"workspace_id: {workspace_id}"))
 
 
 def get_workspace_root_or_throw() -> str:
