@@ -12,8 +12,6 @@ from anyscale.sdk.anyscale_client import (
     StartClusterOptions,
     UpdateCluster,
 )
-from anyscale.sdk.anyscale_client.models import ListResponseMetadata
-from anyscale.sdk.anyscale_client.models.cloud_list_response import CloudListResponse
 
 
 @pytest.fixture()
@@ -503,17 +501,17 @@ def test_is_equal_cluster_compute(mock_prepare_cluster_block):
 def test_get_cloud_id(
     mock_prepare_cluster_block, cloud_name: Optional[str], default_cloud_exists: bool
 ):
-    mock_prepare_cluster_block._get_organization_default_cloud = Mock(
+    mock_get_organization_default_cloud = Mock(
         return_value="default_cloud_name" if default_cloud_exists else None
     )
-    mock_prepare_cluster_block._get_last_used_cloud = Mock(
-        return_value="last_used_cloud_name"
-    )
+    mock_get_last_used_cloud = Mock(return_value="last_used_cloud_name")
     mock_get_cloud_id_and_name = Mock(return_value=("mock_cloud_id", Mock()))
 
     with patch.multiple(
         "anyscale.connect_utils.prepare_cluster",
         get_cloud_id_and_name=mock_get_cloud_id_and_name,
+        get_organization_default_cloud=mock_get_organization_default_cloud,
+        get_last_used_cloud=mock_get_last_used_cloud,
     ):
         assert (
             mock_prepare_cluster_block._get_cloud_id("test_project_id", cloud_name)
@@ -525,91 +523,24 @@ def test_get_cloud_id(
             mock_prepare_cluster_block.api_client, cloud_name=cloud_name
         )
     elif default_cloud_exists:
-        mock_prepare_cluster_block._get_organization_default_cloud.assert_called_once_with()
+        mock_get_organization_default_cloud.assert_called_once_with(
+            mock_prepare_cluster_block.api_client
+        )
         mock_get_cloud_id_and_name.assert_called_once_with(
             mock_prepare_cluster_block.api_client, cloud_name="default_cloud_name"
         )
     else:
-        mock_prepare_cluster_block._get_organization_default_cloud.assert_called_once_with()
-        mock_prepare_cluster_block._get_last_used_cloud.assert_called_once_with(
-            "test_project_id"
+        mock_get_organization_default_cloud.assert_called_once_with(
+            mock_prepare_cluster_block.api_client
+        )
+        mock_get_last_used_cloud.assert_called_once_with(
+            "test_project_id", mock_prepare_cluster_block.anyscale_api_client
         )
         mock_get_cloud_id_and_name.assert_called_once_with(
             mock_prepare_cluster_block.api_client, cloud_name="last_used_cloud_name"
         )
 
 
-@pytest.mark.parametrize("default_cloud_exists", [True, False])
-@pytest.mark.parametrize("default_cloud_permissions_exist", [True, False])
-def test_get_organization_default_cloud(
-    mock_prepare_cluster_block,
-    default_cloud_exists: bool,
-    default_cloud_permissions_exist: bool,
-):
-    mock_user = Mock(
-        organizations=[
-            Mock(
-                default_cloud_id="test_default_cloud_id"
-                if default_cloud_exists
-                else None
-            )
-        ]
-    )
-    mock_prepare_cluster_block.api_client.get_user_info_api_v2_userinfo_get = Mock(
-        return_value=Mock(result=mock_user)
-    )
-    if not default_cloud_permissions_exist:
-        mock_get_cloud_id_and_name = Mock(side_effect=Exception)
-    else:
-        mock_get_cloud_id_and_name = Mock(
-            return_value=("test_default_cloud_id", "test_default_cloud_name")
-        )
-
-    with patch.multiple(
-        "anyscale.connect_utils.prepare_cluster",
-        get_cloud_id_and_name=mock_get_cloud_id_and_name,
-    ):
-        if not default_cloud_exists or not default_cloud_permissions_exist:
-            assert mock_prepare_cluster_block._get_organization_default_cloud() is None
-        else:
-            assert (
-                mock_prepare_cluster_block._get_organization_default_cloud()
-                == "test_default_cloud_name"
-            )
-    mock_prepare_cluster_block.api_client.get_user_info_api_v2_userinfo_get.assert_called_once_with()
-    if default_cloud_exists:
-        mock_get_cloud_id_and_name.assert_called_once_with(
-            mock_prepare_cluster_block.api_client, cloud_id="test_default_cloud_id"
-        )
-
-
-@pytest.mark.parametrize("cloud_id", ["test_cloud_id", None])
-def test_get_last_used_cloud(mock_prepare_cluster_block, cloud_id: Optional[str]):
-    mock_prepare_cluster_block.anyscale_api_client.get_project = Mock(
-        return_value=Mock(result=Mock(last_used_cloud_id=cloud_id))
-    )
-    mock_cloud = Mock(id="test_cloud_id")
-    mock_cloud.name = "test_cloud_name"
-    mock_prepare_cluster_block.anyscale_api_client.get_cloud = Mock(
-        return_value=Mock(result=mock_cloud)
-    )
-    mock_prepare_cluster_block._get_all_clouds = Mock(return_value=[mock_cloud])
-
-    assert (
-        mock_prepare_cluster_block._get_last_used_cloud("test_project_id")
-        == "test_cloud_name"
-    )
-    mock_prepare_cluster_block.anyscale_api_client.get_project.assert_called_once_with(
-        "test_project_id"
-    )
-    if cloud_id:
-        mock_prepare_cluster_block.anyscale_api_client.get_cloud.assert_called_once_with(
-            "test_cloud_id"
-        )
-    else:
-        mock_prepare_cluster_block._get_all_clouds.assert_called_once_with()
-
-
 @pytest.mark.parametrize("build_matches", [True, False])
 @pytest.mark.parametrize("cluster_compute_matches", [True, False])
 @pytest.mark.parametrize("allow_public_internet_traffic_matches", [True, False])
@@ -658,34 +589,6 @@ def test_validate_new_cluster_compute_and_env_match_existing_cluster(
         assert observed_result
 
 
-def test_get_all_clouds(mock_prepare_cluster_block) -> None:
-    mock_cloud_1 = Mock()
-    mock_cloud_1.name = "cloud_1"
-    mock_cloud_2 = Mock()
-    mock_cloud_2.name = "cloud_2"
-
-    mock_prepare_cluster_block.anyscale_api_client.search_clouds.side_effect = [
-        CloudListResponse(
-            results=[mock_cloud_1],
-            metadata=ListResponseMetadata(
-                total=2, next_paging_token="next_paging_token"
-            ),
-        ),
-        CloudListResponse(
-            results=[mock_cloud_2], metadata=ListResponseMetadata(total=2),
-        ),
-    ]
-
-    all_clouds = mock_prepare_cluster_block._get_all_clouds()
-    assert all_clouds == [mock_cloud_1, mock_cloud_2]
-    mock_prepare_cluster_block.anyscale_api_client.search_clouds.assert_has_calls(
-        [
-            call({"paging": {"count": 50}}),
-            call({"paging": {"count": 50, "paging_token": "next_paging_token"}}),
-        ]
-    )
-
-
 @pytest.mark.parametrize(
     "get_prepare_cluster_action",
     [
