@@ -19,6 +19,7 @@ from anyscale.client.openapi_client.models import (
     CloudregionandzonesResponse,
     CloudRegionInfo,
     CloudResponse,
+    ClusterManagementStackVersions,
     CreateCloudResource,
     UpdateCloudWithCloudResource,
     WriteCloud,
@@ -457,6 +458,7 @@ def test_prepare_for_managed_cloud_setup() -> None:
     mock_create_cloud_api_v2_clouds_post = Mock(
         return_value=Mock(result=Mock(id="mock_cloud_id"))
     )
+    cluster_management_stack_version = ClusterManagementStackVersions.V2
 
     with patch.multiple(
         "anyscale.controllers.cloud_controller",
@@ -472,7 +474,9 @@ def test_prepare_for_managed_cloud_setup() -> None:
         (
             anyscale_iam_role_name,
             created_cloud_id,
-        ) = cloud_controller.prepare_for_managed_cloud_setup("us-west-2", "cloud_name")
+        ) = cloud_controller.prepare_for_managed_cloud_setup(
+            "us-west-2", "cloud_name", cluster_management_stack_version
+        )
 
     assert anyscale_iam_role_name == "anyscale-iam-role-02e38860"
     assert created_cloud_id == "mock_cloud_id"
@@ -487,6 +491,7 @@ def test_prepare_for_managed_cloud_setup() -> None:
             credentials=f"arn:aws:iam::mock_user_aws_account_id:role/{anyscale_iam_role_name}",
             name="cloud_name",
             is_bring_your_own_resource=False,
+            cluster_management_stack_version=cluster_management_stack_version,
         )
     )
 
@@ -636,6 +641,7 @@ def test_register_cloud(
             return resource
         raise RuntimeError
 
+    cluster_management_stack_version = ClusterManagementStackVersions.V2
     with patch(
         "anyscale.controllers.cloud_controller.CloudController.verify_aws_cloud_resources",
         new=Mock(return_value=verify_success),
@@ -661,6 +667,7 @@ def test_register_cloud(
                 security_group_ids=mock_security_group_ids,
                 s3_bucket_id=mock_s3_bucket_id,
                 private_network=private_network,
+                cluster_management_stack_version=cluster_management_stack_version,
             )
         else:
             with pytest.raises(ClickException) as e:
@@ -675,6 +682,7 @@ def test_register_cloud(
                     security_group_ids=mock_security_group_ids,
                     s3_bucket_id=mock_s3_bucket_id,
                     private_network=private_network,
+                    cluster_management_stack_version=cluster_management_stack_version,
                 )
             e.match("Please make sure all the resources provided")
     mock_get_role.assert_called_once_with("mock_anyscale_role", mock_region)
@@ -687,6 +695,7 @@ def test_register_cloud(
             name=mock_cloud_name,
             is_bring_your_own_resource=True,
             is_private_cloud=private_network,
+            cluster_management_stack_version=cluster_management_stack_version,
         )
     )
 
@@ -796,6 +805,8 @@ def test_setup_managed_cloud(cloud_setup_failure) -> None:
     mock_run_cloudformation = Mock(return_value=mock_cfn_stack)
     mock_update_cloud_with_resources = Mock()
 
+    cluster_management_stack_version = ClusterManagementStackVersions.V2
+
     if cloud_setup_failure:
         mock_update_cloud_with_resources.side_effect = Exception("ERROR")
 
@@ -810,15 +821,21 @@ def test_setup_managed_cloud(cloud_setup_failure) -> None:
         if cloud_setup_failure:
             with pytest.raises(ClickException):
                 cloud_controller.setup_managed_cloud(
-                    provider="aws", region=mock_region, name=mock_cloud_name
+                    provider="aws",
+                    region=mock_region,
+                    name=mock_cloud_name,
+                    cluster_management_stack_version=cluster_management_stack_version,
                 )
         else:
             cloud_controller.setup_managed_cloud(
-                provider="aws", region=mock_region, name=mock_cloud_name
+                provider="aws",
+                region=mock_region,
+                name=mock_cloud_name,
+                cluster_management_stack_version=cluster_management_stack_version,
             )
 
     mock_prepare_for_managed_cloud_setup.assert_called_with(
-        mock_region, mock_cloud_name
+        mock_region, mock_cloud_name, cluster_management_stack_version
     )
     mock_run_cloudformation.assert_called_with(
         mock_region, mock_cloud_id, mock_anyscale_iam_role_name, mock_ray_iam_role_name
