@@ -654,46 +654,6 @@ def test_verify_aws_security_groups_exist_and_valid(
         assert re.search(expected_log_message, stderr)
 
 
-@pytest.mark.parametrize(
-    ("num_security_groups", "expected_result", "expected_log_message"),
-    [
-        pytest.param(
-            2,
-            True,
-            r"Multiple security groups provided. Only taking the first security group and ignoring the rest.",
-            id="Multiple-SG",
-        ),
-        pytest.param(1, True, None, id="One-SG"),
-    ],
-)
-@mock_ec2
-def test_verify_multiple_aws_security_groups_warning(
-    capsys, num_security_groups: int, expected_result: bool, expected_log_message: str,
-):
-    cloud_resource_mock = generate_cloud_resource_mock_aws()
-    region = "us-west-2"
-
-    sg_id_1 = _create_security_group(region)
-    cloud_resource_mock.aws_security_groups = [sg_id_1]
-
-    for _ in range(num_security_groups):
-        cloud_resource_mock.aws_security_groups.append(_create_security_group(region))
-
-    result = verify_aws_security_groups(
-        cloud_resource=cloud_resource_mock,
-        boto3_session=boto3.Session(region_name=region),
-        logger=BlockLogger(),
-    )
-
-    stdout, stderr = capsys.readouterr()
-    sys.stdout.write(stdout)
-    sys.stderr.write(stderr)
-
-    assert result == expected_result
-    if expected_log_message:
-        assert re.search(expected_log_message, stderr)
-
-
 @pytest.mark.parametrize(
     ("not_enough_permission", "excessive_permission", "expected_log_message"),
     [
