@@ -52,22 +52,20 @@ def test_get_build_id_from_cluster_env_identifier():
         "anyscale.cluster_env",
         get_cluster_env_from_name=mock_get_cluster_env_from_name,
         list_builds=mock_list_builds,
-    ):
-        with pytest.raises(click.ClickException):
-            get_build_from_cluster_env_identifier(
-                "my_cluster_env:3", mock_anyscale_api_client
-            )
+    ), pytest.raises(click.ClickException):
+        get_build_from_cluster_env_identifier(
+            "my_cluster_env:3", mock_anyscale_api_client
+        )
 
     mock_list_builds = Mock(return_value=[])
     with patch.multiple(
         "anyscale.cluster_env",
         get_cluster_env_from_name=mock_get_cluster_env_from_name,
         list_builds=mock_list_builds,
-    ):
-        with pytest.raises(click.ClickException):
-            get_build_from_cluster_env_identifier(
-                "my_cluster_env", mock_anyscale_api_client
-            )
+    ), pytest.raises(click.ClickException):
+        get_build_from_cluster_env_identifier(
+            "my_cluster_env", mock_anyscale_api_client
+        )
 
 
 def test_get_cluster_env_id_from_name():
