@@ -190,7 +190,7 @@ def mock_get_start_interactive_session_block():
         yield mock_get_start_interactive_session_block
 
 
-def _make_test_builder(  # noqa: PLR0915
+def _make_test_builder(
     tmp_path: Path,
     session_states: Optional[List[str]] = None,
     setup_project_dir: bool = True,
@@ -608,7 +608,12 @@ def test_new_proj_connect_params(
     builder.project_dir(project_dir).connect()
 
     mock_get_project_block.assert_called_once_with(
-        project_dir=project_dir, project_name=None, log_output=True,
+        project_dir=project_dir,
+        project_name=None,
+        log_output=True,
+        cloud_name=None,
+        cluster_compute_dict=None,
+        cluster_compute_name=None,
     )
     mock_get_prepare_cluster_block.assert_called_once_with(
         allow_public_internet_traffic=builder._allow_public_internet_traffic,
@@ -789,7 +794,7 @@ def test_disable_cloud_change(tmp_path: Path, project_test_data: Project) -> Non
 
 
 @pytest.mark.parametrize("enable_multiple_clients", [True, False])
-def test_multiple_clients(  # noqa: PLR0913
+def test_multiple_clients(
     enable_multiple_clients: bool,
     tmp_path: Path,
     mock_auth_api_client,
@@ -956,7 +961,7 @@ def test_namespace(mock_auth_api_client) -> None:
 @pytest.mark.parametrize("field", ["pip", "conda"])
 @pytest.mark.parametrize("type", ["python_object", "file"])
 @pytest.mark.parametrize("ray_version", ["1.9.2", "1.10.0", "1.13.0"])
-def test_pin_protobuf_in_runtime_env_if_needed(  # noqa: PLR0913
+def test_pin_protobuf_in_runtime_env_if_needed(
     type, field, ray_version, monkeypatch, tmp_path, mock_auth_api_client  # noqa: A002
 ):
     """Test that protobuf is correctly pinned for old Ray versions.
@@ -1217,7 +1222,7 @@ def test_multiclient_context() -> None:
 
     # Simulates ClientContext.__init__ after changes from
     # https://github.com/ray-project/ray/pull/17942
-    def multiclient_init(  # noqa: PLR0913
+    def multiclient_init(
         self,
         dashboard_url,
         python_version,
@@ -1244,7 +1249,7 @@ def test_multiclient_context() -> None:
 
     # Simulates ClientContext.__init__ from before changes from
     # https://github.com/ray-project/ray/pull/17942
-    def no_multiclient_init(  # noqa: PLR0913
+    def no_multiclient_init(
         self,
         dashboard_url,
         python_version,
