@@ -1,6 +1,7 @@
 import copy
 import json
 import os
+import re
 import time
 from typing import Any, Dict
 from unittest.mock import Mock, patch
@@ -24,6 +25,7 @@ from anyscale.util import (
     str_data_size,
     updating_printer,
 )
+from anyscale.utils.name_utils import gen_valid_name
 from frontend.cli.anyscale.aws_iam_policies import (
     ANYSCALE_IAM_PERMISSIONS_EC2_STEADY_STATE,
     DEFAULT_RAY_IAM_ASSUME_ROLE_POLICY,
@@ -289,7 +291,7 @@ def test_prepare_cloudformation_template():
 
     assert (
         cfn_template
-        == """Description: This tempalte creates the resources necessary for anyscale clouds to function.
+        == """Description: This template creates the resources necessary for an anyscale cloud.
 Transform: AWS::LanguageExtensions
 Parameters:
   EnvironmentName:
@@ -531,6 +533,14 @@ Resources:
       GroupId: !Ref AnyscaleSecurityGroup
       SourceSecurityGroupId: !Ref AnyscaleSecurityGroup
 
+  S3GatewayEndpoint:
+    Type: 'AWS::EC2::VPCEndpoint'
+    Properties:
+      RouteTableIds:
+        - !Ref PublicRouteTable
+      ServiceName: !Sub 'com.amazonaws.${AWS::Region}.s3'
+      VpcId: !Ref VPC
+
   S3Bucket:
     Type: AWS::S3::Bucket
     Description: Anyscale managed s3 bucket.
@@ -1006,3 +1016,12 @@ def test_contains_control_plane_role(assume_role_policy_document, expected_resul
         anyscale_aws_account="000000",
     )
     assert result == expected_result
+
+
+def test_gen_valid_name():
+    NAME_VALIDATION_REGEX_PATTERN = r"^[A-Za-z0-9_-]+$"
+    name_without_prefiex = gen_valid_name()
+    name_with_prefiex = gen_valid_name("test prefix name")
+
+    assert re.match(NAME_VALIDATION_REGEX_PATTERN, name_without_prefiex) is not None
+    assert re.match(NAME_VALIDATION_REGEX_PATTERN, name_with_prefiex) is not None
